@@ -77,12 +77,10 @@ setConstructorS3("GenericDataFileSet", function(files=NULL, tags="*", depth=NULL
 
   setTags(this, tags);
 
-  # TO BE REMOVED/BACKWARD COMPATIBILITY: Argument 'alias'.
+  # TO BE REMOVED. /HB 2013-10-15
   args <- list(...);
   if (is.element("alias", names(args))) {
-    .Deprecated(msg="Argument 'alias' of GenericDataFileSet() is deprecated.  Use fullname translators instead.");
-    alias <- args[["alias"]];
-    if (!is.null(alias)) setAlias(this, alias);
+    .Defunct(msg="Argument 'alias' of GenericDataFileSet() is deprecated.  Use fullname translators instead.");
   }
 
   this;
@@ -271,6 +269,7 @@ setMethodS3("getFileSize", "GenericDataFileSet", function(this, ..., force=FALSE
 
 ###########################################################################/**
 # @RdocMethod getPath
+# @alias getPath
 #
 # @title "Gets the path (directory) of the file set"
 #
@@ -999,6 +998,7 @@ setMethodS3("appendFiles", "GenericDataFileSet", function(this, files, clone=TRU
 
 ###########################################################################/**
 # @RdocMethod append
+# @aliasmethod c
 #
 # @title "Appends one data set to an existing one"
 #
@@ -1051,6 +1051,8 @@ setMethodS3("append", "GenericDataFileSet", function(x, values, ...) {
 
 ###########################################################################/**
 # @RdocMethod extract
+# @alias extract
+# @aliasmethod [
 #
 # @title "Extract a subset of the file set"
 #
@@ -1825,6 +1827,40 @@ setMethodS3("update2", "GenericDataFileSet", function(this, ...) {
 
 
 
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# VECTOR-RELATED METHODS
+#
+# The below implementations, makes the listed "core" methods to work:
+
+# length():
+# * seq_along()
+#
+# length() + [():
+# * rev()
+# * sample()
+#
+# length() + [() + c():
+# * append()
+#
+# ...what else?
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+setMethodS3("[", "GenericDataFileSet", function(x, i, ...) {
+  extract(x, i, ...);
+}, protected=TRUE)
+
+
+setMethodS3("c", "GenericDataFileSet", function(x, ...) {
+  files <- as.list(x);
+  args <- list(...);
+  args <- lapply(args, FUN=function(x) {
+    if (inherits(x, "GenericDataFileSet")) x <- as.list(x);
+    x;
+  });
+  args <- Reduce(c, args);
+  files <- c(files, args);
+  newInstance(x, files);
+}, protected=TRUE)
+
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1999,6 +2035,11 @@ setMethodS3("setFullNamesTranslator", "GenericDataFileSet", function(this, ...)
 
 ############################################################################
 # HISTORY:
+# 2013-10-05
+# o CLEANUP: Now GenericDataFileSet() gives an error informing that
+#   argument 'alias' is defunct.
+# 2013-08-31
+# o Added [() and c() for GenericDataFileSet.
 # 2013-07-28
 # o Added argument 'private=FALSE' to byPath() of GenericDataFileSet.
 # 2012-12-20
