@@ -566,7 +566,7 @@ setMethodS3("getReadArguments", "TabularTextFile", function(this, fileHeader=NUL
       names <- names(colClassPatterns);
       if (length(colClassPatterns) > 1) {
         names <- insert(names[-pos], at=pos, values=rep("*", times=nbrOfColumns));
-        idxs <- whichVector(names == "*");
+        idxs <- which(names == "*");
         names[idxs] <- sprintf("^%s$", columns);
 
         colClassPatterns <- insert(colClassPatterns[-pos], at=pos,
@@ -653,7 +653,7 @@ setMethodS3("getReadArguments", "TabularTextFile", function(this, fileHeader=NUL
 # @synopsis
 #
 # \arguments{
-#   \item{con}{(Internal) If a @connection, then it is used, otherwies
+#   \item{con}{(Internal) If a @connection, then it is used, otherwise
 #   a new file connection is temporarly opened and used.}
 #   \item{rows}{(Optional) An @integer @vector specifying which rows to
 #    be read.}
@@ -720,7 +720,7 @@ setMethodS3("readDataFrame", "TabularTextFile", function(this, con=NULL, rows=NU
     on.exit(popState(verbose));
   }
 
-  verbose && enter(verbose, "Reading ", class(this)[1]);
+  verbose && enter(verbose, "Reading ", class(this)[1L]);
 
 
   # Attributes to be added
@@ -781,9 +781,7 @@ setMethodS3("readDataFrame", "TabularTextFile", function(this, con=NULL, rows=NU
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Reading data
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  fcnName <- "read.table";
-#  fcnName <- "readTable";  ## BUGGY /HB 2008-06-17
-  verbose && enter(verbose, sprintf("Calling %s()", fcnName));
+  verbose && enter(verbose, "Calling read.table()");
 
 
   # SPECIAL CASE/WORKAROUND: read.table()/scan() will give an error
@@ -792,8 +790,8 @@ setMethodS3("readDataFrame", "TabularTextFile", function(this, con=NULL, rows=NU
   # the quotes first. /HB 2011-07-13
 
   # Check if we need to trim quotes
-  trimQuotes <- (trimQuotes && nchar(args$quote) > 0);
-  trimQuotes <- (trimQuotes && length(args$colClasses) > 0);
+  trimQuotes <- (trimQuotes && nchar(args$quote) > 0L);
+  trimQuotes <- (trimQuotes && length(args$colClasses) > 0L);
   if (trimQuotes) {
     classesToPatch <- c("integer", "numeric", "double", "complex");
     toPatch <- is.element(args$colClasses, classesToPatch);
@@ -808,7 +806,7 @@ setMethodS3("readDataFrame", "TabularTextFile", function(this, con=NULL, rows=NU
     verbose && str(verbose, which(toPatch));
     args0 <- args;
 
-    # (1) Read as to-be-patched columns as characters.
+    # (1) Read to-be-patched columns as characters.
     colClasses <- args$colClasses;
     colClasses[toPatch] <- "character";
     args$colClasses <- colClasses;
@@ -817,13 +815,25 @@ setMethodS3("readDataFrame", "TabularTextFile", function(this, con=NULL, rows=NU
   verbose && cat(verbose, "Arguments used to read tabular file:");
   args <- c(list(con), args);
   verbose && print(verbose, args);
-  data <- do.call(fcnName, args=args);
+  data <- do.call(read.table, args=args);
   nbrOfRowsRead <- nrow(data);
   verbose && cat(verbose, "Raw data read by read.table():");
   verbose && str(verbose, data);
   verbose && cat(verbose, "Number of rows read: ", nbrOfRowsRead);
   verbose && cat(verbose, "Number of columns read: ", ncol(data));
 
+  # Extract subset of rows?
+  if (!is.null(rows)) {
+    if (max(rows) > nbrOfRowsRead) {
+      rows <- intersect(rows, 1:nbrOfRowsRead);
+      warning("Argument 'rows' was out of range [1,", nbrOfRowsRead,
+                                "]. Ignored rows beyond this range.");
+    }
+    data <- data[rows,,drop=FALSE];
+  } else {
+    rownames(data) <- NULL;
+  }
+
   # Was data read by first trimming quotes?
   if (trimQuotes) {
     # (2) Re-read numeric columns one by one
@@ -860,7 +870,8 @@ setMethodS3("readDataFrame", "TabularTextFile", function(this, con=NULL, rows=NU
       }, add=TRUE);
 
       # Try to read the values as the correct type.
-      valuesT <- read.table(file=conT, quote="", colClasses=colClass, na.strings=na.strings, blank.lines.skip=FALSE)[[1]];
+      # (Could scan(), which has less overhead, be used here? /HB 2013-09-30)
+      valuesT <- read.table(file=conT, quote="", colClasses=colClass, na.strings=na.strings, blank.lines.skip=FALSE)[[1L]];
 
       verbose && cat(verbose, "Parsed values:");
       verbose && str(verbose, valuesT);
@@ -878,27 +889,11 @@ setMethodS3("readDataFrame", "TabularTextFile", function(this, con=NULL, rows=NU
     verbose && exit(verbose);
 
     verbose && exit(verbose);
-  }
+  } # if (trimQuotes)
 
 
-  # Extract subset of rows?
-  if (fcnName == "read.table") {
-    if (!is.null(rows)) {
-      if (max(rows) > nbrOfRowsRead) {
-        rows <- intersect(rows, 1:nbrOfRowsRead);
-        warning("Argument 'rows' was out of range [1,", nbrOfRowsRead,
-                                  "]. Ignored rows beyond this range.");
-      }
-      data <- data[rows,,drop=FALSE];
-    } else {
-      rownames(data) <- NULL;
-    }
-  } else {
-    rownames(data) <- NULL;
-  }
-
   # Sanity check
-  if (length(columns) > 0) {
+  if (length(columns) > 0L) {
     if (ncol(data) != length(columns)) {
       throw("Number of read data columns does not match the number of column headers: ", ncol(data), " !=", length(columns));
     }
@@ -1118,6 +1113,12 @@ setMethodS3("readLines", "TabularTextFile", function(con, ...) {
 
 ############################################################################
 # HISTORY:
+# 2013-09-30
+# o Now readDataFrame() for TabularTextFile subsets by row, if requested,
+#   before reparsing numerical columns that were quoted.
+# 2013-09-23
+# o SPEEDUP/CLEANUP: Package no longer uses R.utils::whichVector(), which
+#   use to be 10x faster, but since R 2.11.0 which() is 3x times faster.
 # 2013-01-17
 # o In addition to a fixed integer, argument 'skip' for readDataFrame()
 #   (default and for TabularTextFile) may also specify a regular
